@@ -2,7 +2,6 @@ import datetime
 import importlib
 import logging
 import os
-import subprocess
 import sys
 import tempfile
 from contextlib import contextmanager, nullcontext
@@ -15,12 +14,15 @@ import pendulum
 from airflow import __version__ as airflow_version
 from airflow.models import TaskInstance
 from airflow.models.baseoperator import BaseOperator
+from airflow.models.connection import Connection
 from airflow.models.dag import DAG
 from airflow.models.dagbag import DagBag
 from airflow.settings import LOG_FORMAT
+from airflow.utils import db
 from dagster_airflow.patch_airflow_example_dag import patch_airflow_example_dag
 
 from dagster import (
+    Array,
     DagsterInvariantViolationError,
     DependencyDefinition,
     Field,
@@ -33,16 +35,19 @@ from dagster import (
 )
 from dagster import _check as check
 from dagster import op, repository, resource
+from dagster._core.definitions.op_definition import OpDefinition
 from dagster._core.definitions.utils import VALID_NAME_REGEX, validate_tags
 from dagster._core.instance import AIRFLOW_EXECUTION_DATE_STR, IS_AIRFLOW_INGEST_PIPELINE_STR
-from dagster._legacy import ModeDefinition, PipelineDefinition, SolidDefinition
+from dagster._legacy import ModeDefinition, PipelineDefinition
 from dagster._utils.schedules import is_valid_cron_schedule
 
 # pylint: disable=no-name-in-module,import-error
 if str(airflow_version) >= "2.0.0":
+    from airflow.utils.session import create_session
     from airflow.utils.state import DagRunState
     from airflow.utils.types import DagRunType
 else:
+    from airflow.utils.db import create_session
     from airflow.utils.state import State
 # pylint: enable=no-name-in-module,import-error
 
@@ -86,12 +91,18 @@ class Locker:
         self.fp.close()
 
 
-def initialize_airflow_1_database():
-    subprocess.run(["airflow", "initdb"], check=True)
+def create_airflow_connections(connections):
+    with create_session() as session:
+        for connection in connections:
+            if session.query(Connection).filter(Connection.conn_id == connection.conn_id).first():
+                logging.info(
+                    f"Could not import connection {connection.conn_id}: connection already exists."
+                )
+                continue
 
-
-def initialize_airflow_2_database():
-    subprocess.run(["airflow", "db", "init"], check=True)
+            session.add(connection)
+            session.commit()
+            logging.info(f"Imported connection {connection.conn_id}")
 
 
 def contains_duplicate_task_names(dag_bag, refresh_from_airflow_db):
@@ -118,6 +129,7 @@ def make_dagster_repo_from_airflow_dag_bag(
     use_airflow_template_context=False,
     mock_xcom=False,
     use_ephemeral_airflow_db=False,
+    connections=None,
 ):
     """Construct a Dagster repository corresponding to Airflow DAGs in DagBag.
 
@@ -146,6 +158,8 @@ def make_dagster_repo_from_airflow_dag_bag(
             depend on xcom may not work as expected. (default: False)
         use_ephemeral_airflow_db (bool): If True, dagster will create an ephemeral sqlite airflow
             database for each run. (default: False)
+        connections (List[Connection]): List of Airflow Connections to be created in the Ephemeral
+            Airflow DB, if use_emphemeral_airflow_db is False this will be ignored.
 
     Returns:
         RepositoryDefinition
@@ -158,6 +172,7 @@ def make_dagster_repo_from_airflow_dag_bag(
     use_ephemeral_airflow_db = check.opt_bool_param(
         use_ephemeral_airflow_db, "use_ephemeral_airflow_db"
     )
+    connections = check.opt_list_param(connections, "connections", of_type=Connection)
 
     use_unique_id = contains_duplicate_task_names(dag_bag, refresh_from_airflow_db)
 
@@ -177,6 +192,7 @@ def make_dagster_repo_from_airflow_dag_bag(
                 use_airflow_template_context=use_airflow_template_context,
                 mock_xcom=mock_xcom,
                 use_ephemeral_airflow_db=use_ephemeral_airflow_db,
+                connections=connections,
             )
         else:
             pipeline_def = make_dagster_pipeline_from_airflow_dag(
@@ -186,6 +202,7 @@ def make_dagster_repo_from_airflow_dag_bag(
                 unique_id=count,
                 mock_xcom=mock_xcom,
                 use_ephemeral_airflow_db=use_ephemeral_airflow_db,
+                connections=connections,
             )
             count += 1
         # pass in tags manually because pipeline_def.graph doesn't have it threaded
@@ -299,7 +316,7 @@ def make_dagster_repo_from_airflow_example_dags(
     patch_airflow_example_dag(dag_bag)
 
     return make_dagster_repo_from_airflow_dag_bag(
-        dag_bag, repo_name, use_ephemeral_airflow_db=use_ephemeral_airflow_db
+        dag_bag=dag_bag, repo_name=repo_name, use_ephemeral_airflow_db=use_ephemeral_airflow_db
     )
 
 
@@ -311,6 +328,7 @@ def make_dagster_repo_from_airflow_dags_path(
     use_airflow_template_context=False,
     mock_xcom=False,
     use_ephemeral_airflow_db=True,
+    connections=None,
 ):
     """Construct a Dagster repository corresponding to Airflow DAGs in dag_path.
 
@@ -347,6 +365,8 @@ def make_dagster_repo_from_airflow_dags_path(
             depend on xcom may not work as expected. (default: False)
         use_ephemeral_airflow_db (bool): If True, dagster will create an ephemeral sqlite airflow
             database for each run. (default: False)
+        connections (List[Connection]): List of Airflow Connections to be created in the Ephemeral
+            Airflow DB, if use_emphemeral_airflow_db is False this will be ignored.
 
     Returns:
         RepositoryDefinition
@@ -360,6 +380,9 @@ def make_dagster_repo_from_airflow_dags_path(
     use_ephemeral_airflow_db = check.opt_bool_param(
         use_ephemeral_airflow_db, "use_ephemeral_airflow_db"
     )
+    connections = check.opt_list_param(connections, "connections", of_type=Connection)
+    # add connections as environment variables so that dag evaluation works
+    create_airflow_connections(connections)
     try:
         dag_bag = DagBag(
             dag_folder=dag_path,
@@ -370,11 +393,12 @@ def make_dagster_repo_from_airflow_dags_path(
         raise DagsterAirflowError("Error initializing airflow.models.dagbag object with arguments")
 
     return make_dagster_repo_from_airflow_dag_bag(
-        dag_bag,
-        repo_name,
+        dag_bag=dag_bag,
+        repo_name=repo_name,
         use_airflow_template_context=use_airflow_template_context,
         mock_xcom=mock_xcom,
         use_ephemeral_airflow_db=use_ephemeral_airflow_db,
+        connections=connections,
     )
 
 
@@ -385,6 +409,7 @@ def make_dagster_pipeline_from_airflow_dag(
     unique_id=None,
     mock_xcom=False,
     use_ephemeral_airflow_db=False,
+    connections=None,
 ):
     """Construct a Dagster pipeline corresponding to a given Airflow DAG.
 
@@ -439,6 +464,8 @@ def make_dagster_pipeline_from_airflow_dag(
             depend on xcom may not work as expected.
         use_ephemeral_airflow_db (bool): If True, dagster will create an ephemeral sqlite airflow
             database for each run
+        connections (List[Connection]): List of Airflow Connections to be created in the Ephemeral
+            Airflow DB, if use_emphemeral_airflow_db is False this will be ignored.
 
     Returns:
         pipeline_def (PipelineDefinition): The generated Dagster pipeline
@@ -452,6 +479,7 @@ def make_dagster_pipeline_from_airflow_dag(
     use_ephemeral_airflow_db = check.opt_bool_param(
         use_ephemeral_airflow_db, "use_ephemeral_airflow_db"
     )
+    connections = check.opt_list_param(connections, "connections", of_type=Connection)
 
     if IS_AIRFLOW_INGEST_PIPELINE_STR not in tags:
         tags[IS_AIRFLOW_INGEST_PIPELINE_STR] = "true"
@@ -459,13 +487,44 @@ def make_dagster_pipeline_from_airflow_dag(
     tags = validate_tags(tags)
 
     pipeline_dependencies, solid_defs = _get_pipeline_definition_args(
-        dag, use_airflow_template_context, unique_id, mock_xcom, use_ephemeral_airflow_db
+        dag=dag,
+        use_airflow_template_context=use_airflow_template_context,
+        unique_id=unique_id,
+        mock_xcom=mock_xcom,
+        use_ephemeral_airflow_db=use_ephemeral_airflow_db,
     )
 
+    serialized_connections = []
+    for c in connections:
+        serialized_connection = {
+            "conn_id": c.conn_id,
+            "conn_type": c.conn_type,
+        }
+        if hasattr(c, "login") and c.login:
+            serialized_connection["login"] = c.login
+        if hasattr(c, "password") and c.password:
+            serialized_connection["password"] = c.password
+        if hasattr(c, "host") and c.host:
+            serialized_connection["host"] = c.host
+        if hasattr(c, "schema") and c.schema:
+            serialized_connection["schema"] = c.schema
+        if hasattr(c, "port") and c.port:
+            serialized_connection["port"] = c.port
+        if hasattr(c, "extra") and c.extra:
+            serialized_connection["extra"] = c.extra
+        if hasattr(c, "description") and c.description:
+            serialized_connection["description"] = c.description
+        serialized_connections.append(serialized_connection)
+
     @resource(
         config_schema={
             "dag_location": Field(str, default_value=dag.fileloc),
             "dag_id": Field(str, default_value=dag.dag_id),
+            "connections": Field(
+                Array(inner_type=dict),
+                default_value=serialized_connections,
+                is_required=False,
+            ),
         }
     )
     def airflow_db(context):
@@ -474,11 +533,6 @@ def make_dagster_pipeline_from_airflow_dag(
         os.makedirs(airflow_home_path, exist_ok=True)
         with Locker(airflow_home_path):
             airflow_initialized = os.path.exists(f"{airflow_home_path}/airflow.db")
-            if not airflow_initialized:
-                if airflow_version >= "2.0.0":
-                    initialize_airflow_2_database()
-                else:
-                    initialize_airflow_1_database()
             # because AIRFLOW_HOME has been overriden airflow needs to be reloaded
             if airflow_version >= "2.0.0":
                 importlib.reload(airflow.configuration)
@@ -486,9 +540,14 @@ def make_dagster_pipeline_from_airflow_dag(
                 importlib.reload(airflow)
             else:
                 importlib.reload(airflow)
+            if not airflow_initialized:
+                db.initdb()
+                create_airflow_connections(
+                    [Connection(**c) for c in context.resource_config["connections"]]
+                )
 
             dag_bag = airflow.models.dagbag.DagBag(
-                dag_folder=context.resource_config["dag_location"], include_examples=True
+                dag_folder=context.resource_config["dag_location"], include_examples=False
             )
             dag = dag_bag.get_dag(context.resource_config["dag_id"])
             execution_date_str = context.dagster_run.tags.get(AIRFLOW_EXECUTION_DATE_STR)
@@ -559,15 +618,15 @@ def _get_pipeline_definition_args(
     dag_roots = sorted(dag.roots, key=lambda x: x.task_id)
     for task in dag_roots:
         _traverse_airflow_dag(
-            dag,
-            task,
-            seen_tasks,
-            pipeline_dependencies,
-            solid_defs,
-            use_airflow_template_context,
-            unique_id,
-            mock_xcom,
-            use_ephemeral_airflow_db,
+            dag=dag,
+            task=task,
+            seen_tasks=seen_tasks,
+            pipeline_dependencies=pipeline_dependencies,
+            solid_defs=solid_defs,
+            use_airflow_template_context=use_airflow_template_context,
+            unique_id=unique_id,
+            mock_xcom=mock_xcom,
+            use_ephemeral_airflow_db=use_ephemeral_airflow_db,
         )
     return (pipeline_dependencies, solid_defs)
 
@@ -586,7 +645,7 @@ def _traverse_airflow_dag(
     check.inst_param(dag, "dag", DAG)
     check.inst_param(task, "task", BaseOperator)
     check.list_param(seen_tasks, "seen_tasks", BaseOperator)
-    check.list_param(solid_defs, "solid_defs", SolidDefinition)
+    check.list_param(solid_defs, "solid_defs", OpDefinition)
     check.bool_param(use_airflow_template_context, "use_airflow_template_context")
     unique_id = check.opt_int_param(unique_id, "unique_id")
     mock_xcom = check.opt_bool_param(mock_xcom, "mock_xcom")
@@ -596,7 +655,12 @@ def _traverse_airflow_dag(
 
     seen_tasks.append(task)
     current_solid = make_dagster_solid_from_airflow_task(
-        dag, task, use_airflow_template_context, unique_id, mock_xcom, use_ephemeral_airflow_db
+        dag=dag,
+        task=task,
+        use_airflow_template_context=use_airflow_template_context,
+        unique_id=unique_id,
+        mock_xcom=mock_xcom,
+        use_ephemeral_airflow_db=use_ephemeral_airflow_db,
     )
     solid_defs.append(current_solid)
 
@@ -621,15 +685,15 @@ def _traverse_airflow_dag(
     for child_task in task_downstream_list:
         if child_task not in seen_tasks:
             _traverse_airflow_dag(
-                dag,
-                child_task,
-                seen_tasks,
-                pipeline_dependencies,
-                solid_defs,
-                use_airflow_template_context,
-                unique_id,
-                mock_xcom,
-                use_ephemeral_airflow_db,
+                dag=dag,
+                task=child_task,
+                seen_tasks=seen_tasks,
+                pipeline_dependencies=pipeline_dependencies,
+                solid_defs=solid_defs,
+                use_airflow_template_context=use_airflow_template_context,
+                unique_id=unique_id,
+                mock_xcom=mock_xcom,
+                use_ephemeral_airflow_db=use_ephemeral_airflow_db,
             )
 
 
@@ -685,6 +749,8 @@ def make_dagster_solid_from_airflow_task(
         },
     )
     def _solid(context):  # pylint: disable=unused-argument
+        # reloading forces picking up any config that's been set for execution
+        importlib.reload(airflow)
         mock_xcom = context.op_config["mock_xcom"]
         use_ephemeral_airflow_db = context.op_config["use_ephemeral_airflow_db"]
         if AIRFLOW_EXECUTION_DATE_STR not in context.pipeline_run.tags:
