@@ -5,7 +5,7 @@ from dagster_airflow.vendor.python_operator import PythonOperator
 
 class DagsterPythonOperator(PythonOperator):
     def __init__(self, dagster_operator_parameters, *args, **kwargs):
-        def python_callable(ts, dag_run, **kwargs):  # pylint: disable=unused-argument
+        def python_callable(ts, dag_run, *_args, **kwargs):
             return invoke_steps_within_python_operator(
                 dagster_operator_parameters.invocation_args, ts, dag_run, **kwargs
             )
